@@ -613,7 +613,8 @@ sub setup_actions {
       $self->_load_dispatch_types( @{ $self->preload_dispatch_types } );
     @{ $self->_registered_dispatch_types }{@classes} = (1) x @classes;
 
-    foreach my $comp ( values %{ $c->components } ) {
+    foreach my $comp_key ( keys %{ $c->components } ) {
+      my $comp = $c->component($comp_key);
         $comp->register_actions($c) if $comp->can('register_actions');
     }
 
